@@ -32,7 +32,7 @@ def get_args():
   return args
 
 def is_args_valid(args):
-  print(args + "2")
+  print(args)
   valid_args =  all(arg in valid_args_list for arg in args)
   return valid_args
 
